@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.005_05';
+our $VERSION = '0.005_06';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -23,6 +23,7 @@ use File::Copy qw/move/;
 use Env qw( @PATH );
 use Shell::Guess;
 use Shell::Config::Generate;
+use File::Path qw/mkpath/;
 
 use Alien::Base::PkgConfig;
 use Alien::Base::ModuleBuild::Cabinet;
@@ -235,6 +236,20 @@ sub ACTION_code {
     # copy the compiled files into blib if running under blib scheme
     $self->depends_on('alien_install') if $self->notes('alien_blib_scheme');
   }
+  
+  my $module = $self->module_name;
+  my $file   = File::Spec->catfile($self->blib, 'lib', split /::/, "$module\::Install::Files.pm");
+  unless (-e $file) {
+    mkpath(File::Spec->catdir($self->blib, 'lib', split /::/, "$module\::Install"), { verbose => 0 });
+    open my $fh, '>', $file;
+    print $fh <<EOF;
+package $module\::Install::Files;
+require $module;
+sub Inline { shift; $module->Inline(\@_) }
+1;
+EOF
+    close $fh;
+  }
 }
 
 sub ACTION_alien_code {
@@ -305,6 +320,11 @@ sub ACTION_alien_code {
     $pc->{$self->alien_name} || $pc->{_manual}
   )->keyword('Version');
 
+  unless (defined $version) {
+    local $CWD = $self->config_data( 'working_directory' );
+    $version = $self->alien_check_built_version
+  }
+
   if (! $version and ! $pc_version) {
     carp "Library looks like it installed, but no version was determined";
     $self->config_data( version => 0 );    
@@ -586,6 +606,10 @@ sub _env_do_system {
   $self->do_system( $command );
 }
 
+sub alien_check_built_version {
+  return;
+}
+
 sub alien_do_commands {
   my $self = shift;
   my $phase = shift;
@@ -963,6 +987,42 @@ build step of your distribution.  When properly configured it will
 
 =back
 
+=head1 METHODS
+
+=head2 alien_check_instaled_version
+
+ my $version = $abmb->alien_check_installed_version;
+
+This function determines if the library is already installed as part of
+the operating system, and returns the version as a string.  If it can't
+be detected then it should return empty list.
+
+The default implementation relies on C<pkg-config>, but you will probably
+want to override this with your own implementation if the package you are
+building does not use C<pkg-config>.
+
+=head2 alien_check_built_version
+
+ my $version = $amb->alien_check_built_version;
+
+This function determines the version of the library after it has been
+built from source.  This function only gets called if the operating
+system version can not be found and the package is successfully built.
+
+The default implementation relies on C<pkg-config>, and other huristics,
+but you will probably want to override this with your own implementation
+if the package you are building does not use C<pkg-config>.
+
+When this method is called, the current working directory will be the
+build root.
+
+If you see an error message like this:
+
+ Library looks like it installed, but no version was determined
+
+After the package is built from source code then you probably need to
+provide an implementation for this method.
+
 =head1 GUIDE TO DOCUMENTATION
 
 The documentation for C<Module::Build> is broken up into sections:
